Ipv6ParseError

Enum Ipv6ParseError 

pub enum Ipv6ParseError {
    Parse {
        error: ParseError,
    },
    ParameterProblem {
        src_ip: Ipv6Addr,
        dst_ip: Ipv6Addr,
        code: Icmpv6ParameterProblemCode,
        pointer: u32,
        must_send_icmp: bool,
        action: IpParseErrorAction,
    },
}
Error type for IP packet parsing. Error when parsing an IPv6 packet.

Variants



Parse

Fields



ParameterProblem

For errors where an ICMP Parameter Problem error needs to be sent to the source of a packet.

Fields

src_ip: Ipv6Addr

The packet’s source IP address.

dst_ip: Ipv6Addr

The packet’s destination IP address.

code: Icmpv6ParameterProblemCode

The ICMPv6 parameter problem code that provides more granular information about the parameter problem encountered.

pointer: u32

The offset of the erroneous value within the IP packet.

must_send_icmp: bool

Whether an IP node MUST send an ICMP response if action specifies it.

See action for more details.

action: IpParseErrorAction

The action IP nodes should take upon encountering this error.

If must_send_icmp is true, IP nodes MUST send an ICMP response if action specifies it. Otherwise, the node MAY choose to discard the packet and do nothing further.