pub trait IcmpMessageType:
TryFrom<u8>
+ Into<u8>
+ Copy
+ Debug {
// Required method
fn is_error_or_redirect(self) -> bool;
}Expand description
The type of an ICMP message.
IcmpMessageType is implemented by Icmpv4MessageType and
Icmpv6MessageType.
Required Methods
Sourcefn is_error_or_redirect(self) -> bool
fn is_error_or_redirect(self) -> bool
Is this an error message?
For ICMP, this is true for the Destination Unreachable, Redirect, Source Quench, Time Exceeded, and Parameter Problem message types. For ICMPv6, this is true for the Destination Unreachable, Packet Too Big, Time Exceeded, and Parameter Problem message types.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.