pub struct TcpSegment<B> { /* private fields */ }Expand description
A TCP segment.
A TcpSegment shares its underlying memory with the byte slice it was
parsed from or serialized to, meaning that no copying or extra allocation is
necessary.
A TcpSegment - whether parsed using parse or created using
TcpSegmentBuilder - maintains the invariant that the checksum is always
valid.
Implementations
Sourceimpl<B: SplitByteSlice> TcpSegment<B>
impl<B: SplitByteSlice> TcpSegment<B>
Sourcepub fn options(&self) -> &TcpOptionsRef<B>
pub fn options(&self) -> &TcpOptionsRef<B>
Returns the segment’s options.
Sourcepub fn into_body(self) -> B
pub fn into_body(self) -> B
Consumes this packet and returns the body.
Note that the returned B has the same lifetime as the buffer from
which this segment was parsed. By contrast, the body method returns
a slice with the same lifetime as the receiver.
Sourcepub fn src_port(&self) -> NonZeroU16
pub fn src_port(&self) -> NonZeroU16
The source port.
Sourcepub fn dst_port(&self) -> NonZeroU16
pub fn dst_port(&self) -> NonZeroU16
The destination port.
Sourcepub fn ack_num(&self) -> Option<u32>
pub fn ack_num(&self) -> Option<u32>
The acknowledgement number.
If the ACK flag is not set, ack_num returns None.
Sourcepub fn flags(&self) -> u8
pub fn flags(&self) -> u8
The segment’s flag bits: the six control flags and the two ECN flags.
Sourcepub fn reserved_bits(&self) -> u8
pub fn reserved_bits(&self) -> u8
The segment’s reserved bits, held in the low nibble of the returned byte.
Sourcepub fn window_size(&self) -> u16
pub fn window_size(&self) -> u16
The sender’s window size.
Sourcepub fn header_len(&self) -> usize
pub fn header_len(&self) -> usize
The length of the header prefix and options.
Sourcepub fn total_segment_len(&self) -> usize
pub fn total_segment_len(&self) -> usize
The length of the segment as calculated from the header prefix, options, and body.
Sourcepub fn recover_payload_partial_sum<I: Ip>(
&self,
src_ip: I::Addr,
dst_ip: I::Addr,
) -> Result<[u8; 2], TryFromIntError>
pub fn recover_payload_partial_sum<I: Ip>( &self, src_ip: I::Addr, dst_ip: I::Addr, ) -> Result<[u8; 2], TryFromIntError>
Recovers the 1’s complement partial sum of the TCP segment body (payload) without hashing the payload bytes.
The sender computes tcp_checksum = ~(sum(pseudo_hdr) + sum(tcp_hdr_csum_zero) + sum(payload)). In 1’s complement arithmetic
(RFC 1624), subtracting a sum S is equivalent to adding ~S.
Removing the pseudo header and the wire header prefix and options
subtracts sum(pseudo_hdr) + sum(tcp_hdr_csum_zero) + sum(tcp_checksum). Adding tcp_checksum back cancels out the checksum
field subtraction and leaves exactly ~sum(payload). Inverting that
produces the partial sum sum(payload).
Returns an error if the TCP segment exceeds the maximum length representable by the IP pseudo-header.
Sourcepub fn builder<A: IpAddress>(
&self,
src_ip: A,
dst_ip: A,
) -> TcpSegmentBuilderWithOptions<A, &TcpOptionsRef<B>>
pub fn builder<A: IpAddress>( &self, src_ip: A, dst_ip: A, ) -> TcpSegmentBuilderWithOptions<A, &TcpOptionsRef<B>>
Constructs a builder with the same contents as this packet.
Sourcepub fn into_builder<A: IpAddress>(
self,
src_ip: A,
dst_ip: A,
) -> TcpSegmentBuilderWithOptions<A, TcpOptionsRef<B>>
pub fn into_builder<A: IpAddress>( self, src_ip: A, dst_ip: A, ) -> TcpSegmentBuilderWithOptions<A, TcpOptionsRef<B>>
Consumes this segment and constructs a builder with the same contents.
Unlike TcpSegment::builder, the returned builder’s options borrow
from B rather than from self, so the builder can outlive this
TcpSegment.
Sourcepub fn into_serializer<'a, A: IpAddress>(
self,
src_ip: A,
dst_ip: A,
) -> impl Serializer<NoOpSerializationContext, Buffer = EmptyBuf> + Debug + 'awhere
B: 'a,
pub fn into_serializer<'a, A: IpAddress>(
self,
src_ip: A,
dst_ip: A,
) -> impl Serializer<NoOpSerializationContext, Buffer = EmptyBuf> + Debug + 'awhere
B: 'a,
Consumes this segment and constructs a Serializer with the same
contents.
The returned Serializer has the Buffer type EmptyBuf, which
means it is not able to reuse the buffer backing this TcpSegment when
serializing, and will always need to allocate a new buffer.
By consuming self instead of taking it by-reference, into_serializer
is able to return a Serializer whose lifetime is restricted by the
lifetime of the buffer from which this TcpSegment was parsed rather
than by the lifetime on &self, which may be more restricted.
Sourceimpl<B: SplitByteSliceMut> TcpSegment<B>
impl<B: SplitByteSliceMut> TcpSegment<B>
Sourcepub fn set_src_port(&mut self, new: NonZeroU16)
pub fn set_src_port(&mut self, new: NonZeroU16)
Set the source port of the TCP packet.
Sourcepub fn set_dst_port(&mut self, new: NonZeroU16)
pub fn set_dst_port(&mut self, new: NonZeroU16)
Set the destination port of the TCP packet.
Sourcepub fn update_checksum_pseudo_header_address<A: IpAddress>(
&mut self,
old: A,
new: A,
)
pub fn update_checksum_pseudo_header_address<A: IpAddress>( &mut self, old: A, new: A, )
Update the checksum to reflect an updated address in the pseudo header.