pub struct ForceChecksumAction(pub TransportChecksumAction);Expand description
A SerializationContext that forces a specific transport-layer
checksum action to be used.
Tuple Fields
0: TransportChecksumActionTrait Implementations
Sourceimpl SerializationContext for ForceChecksumAction
impl SerializationContext for ForceChecksumAction
Sourcetype ContextState = ()
type ContextState = ()
The packet-specific state required by this serialization context.
Sourcefn serialize_nested<O, R>(
&mut self,
_outer: &O,
constraints: PacketConstraints,
serialize_fn: impl FnOnce(&mut Self, PacketConstraints) -> R,
) -> Rwhere
O: PacketBuilder<Self>,
fn serialize_nested<O, R>(
&mut self,
_outer: &O,
constraints: PacketConstraints,
serialize_fn: impl FnOnce(&mut Self, PacketConstraints) -> R,
) -> Rwhere
O: PacketBuilder<Self>,
Performs nested serialization within the context of an outer
PacketBuilder. Read moreSourceimpl TcpSerializationContext for ForceChecksumAction
impl TcpSerializationContext for ForceChecksumAction
Sourcefn envelope_to_state(_envelope: TcpEnvelope) -> Self::ContextState
fn envelope_to_state(_envelope: TcpEnvelope) -> Self::ContextState
Converts a
TcpEnvelope into the serialization context’s state.Sourcefn checksum_action(&mut self) -> TransportChecksumAction
fn checksum_action(&mut self) -> TransportChecksumAction
Returns the checksum action to take based on the serialization context.
Sourceimpl UdpSerializationContext for ForceChecksumAction
impl UdpSerializationContext for ForceChecksumAction
Sourcefn envelope_to_state(_envelope: UdpEnvelope) -> Self::ContextState
fn envelope_to_state(_envelope: UdpEnvelope) -> Self::ContextState
Converts a
UdpEnvelope into the serialization context’s state.Sourcefn checksum_action(&mut self) -> TransportChecksumAction
fn checksum_action(&mut self) -> TransportChecksumAction
Returns the checksum action to take based on the serialization context.