pub struct ForceSkipChecksumValidation(pub bool);Expand description
A TcpParseContext and UdpParseContext that forces a specific
checksum validation action to be used (or skipped).
Tuple Fields
0: boolTrait Implementations
Sourceimpl TcpParseContext for ForceSkipChecksumValidation
impl TcpParseContext for ForceSkipChecksumValidation
Sourcefn skip_checksum_verification(&mut self) -> bool
fn skip_checksum_verification(&mut self) -> bool
Returns true if the checksum verification should be skipped.
Sourceimpl UdpParseContext for ForceSkipChecksumValidation
impl UdpParseContext for ForceSkipChecksumValidation
Sourcefn skip_checksum_verification(&mut self) -> bool
fn skip_checksum_verification(&mut self) -> bool
Returns true if the checksum verification should be skipped.