pub enum Ipv6ParseError {
Parse {
error: ParseError,
},
ParameterProblem {
src_ip: Ipv6Addr,
dst_ip: Ipv6Addr,
code: Icmpv6ParameterProblemCode,
pointer: u32,
must_send_icmp: bool,
action: IpParseErrorAction,
},
}Expand description
Error type for IP packet parsing. Error when parsing an IPv6 packet.
Variants
Parse
Fields

error: ParseErrorParameterProblem
For errors where an ICMP Parameter Problem error needs to be sent to the source of a packet.
Fields

code: Icmpv6ParameterProblemCodeThe ICMPv6 parameter problem code that provides more granular information about the parameter problem encountered.

action: IpParseErrorActionThe action IP nodes should take upon encountering this error.
If must_send_icmp is true, IP nodes MUST send an ICMP response
if action specifies it. Otherwise, the node MAY choose to discard
the packet and do nothing further.