TcpParseContext

Trait TcpParseContext 

pub trait TcpParseContext {
    // Required method
    fn skip_checksum_verification(&mut self) -> bool;
}
Context for parsing TCP segments that may be subject to hardware checksum offloading.

Required Methods

fn skip_checksum_verification(&mut self) -> bool

Returns true if the checksum verification should be skipped.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl TcpParseContext for NoOpParsingContext

Implementors