pub trait TcpParseContext {
// Required method
fn skip_checksum_verification(&mut self) -> bool;
}Expand description
Context for parsing TCP segments that may be subject to hardware checksum offloading.
Required Methods
Sourcefn skip_checksum_verification(&mut self) -> bool
fn skip_checksum_verification(&mut self) -> bool
Returns true if the checksum verification should be skipped.