UdpParseContext

Trait UdpParseContext 

pub trait UdpParseContext {
    // Required method
    fn skip_checksum_verification(&mut self) -> bool;
}
Context for parsing UDP packets that may be subject to hardware checksum offloading.

Required Methods

fn skip_checksum_verification(&mut self) -> bool

Returns true if the checksum verification should be skipped.

Implementations on Foreign Types

Source

impl UdpParseContext for NoOpParsingContext

Implementors